==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-panel/plugin-taskbar/taskbar_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>LXQtTaskButton</name>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="477"/>
        <source>Application</source>
        <translation>Toepassing</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="511"/>
        <source>To &amp;Desktop</source>
        <translation>Naar &amp;bureaublad</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="513"/>
        <source>&amp;All Desktops</source>
        <translation>&amp;Alle bureaubladen</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="521"/>
        <source>Desktop &amp;%1</source>
        <translation>Bureaublad &amp;%1</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="528"/>
        <source>&amp;To Current Desktop</source>
        <translation>&amp;Naar huidig bureaublad</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="537"/>
        <source>Ma&amp;ximize</source>
        <translation>Ma&amp;ximaliseren</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="544"/>
        <source>Maximize vertically</source>
        <translation>Verticaal maximaliseren</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="549"/>
        <source>Maximize horizontally</source>
        <translation>Horizontaal maximaliseren</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="555"/>
        <source>&amp;Restore</source>
        <translation>&amp;Herstellen</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="559"/>
        <source>Mi&amp;nimize</source>
        <translation>Mi&amp;nimaliseren</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="565"/>
        <source>Roll down</source>
        <translation>Uitrollen</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="571"/>
        <source>Roll up</source>
        <translation>Oprollen</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="579"/>
        <source>&amp;Layer</source>
        <translation>&amp;Laag</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="581"/>
        <source>Always on &amp;top</source>
        <translation>Altijd bovenop</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="587"/>
        <source>&amp;Normal</source>
        <translation>&amp;Normaal</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="593"/>
        <source>Always on &amp;bottom</source>
        <translation>Altijd onderop</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="601"/>
        <source>&amp;Close</source>
        <translation>&amp;Sluiten</translation>
    </message>
</context>
<context>
    <name>LXQtTaskGroup</name>
    <message>
        <location filename="../../../lxqttaskgroup.cpp" line="83"/>
        <source>Group</source>
        <translation>Groep</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskgroup.cpp" line="85"/>
        <source>Close group</source>
        <translation>Sluit groep</translation>
    </message>
</context>
<context>
    <name>LXQtTaskbarConfiguration</name>
    <message>
        <source>LXQt Task Manager Settings</source>
        <translation type="vanished">Instellingen voor taakbeheerder van LXQt</translation>
    </message>
    <message>
        <source>Window List Content</source>
        <translation type="vanished">Inhoud van vensterlijst</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="14"/>
        <source>Task Manager Settings</source>
        <translation>Instellingen van taakbeheerder</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Algemeen</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="34"/>
        <source>Show only windows from desktop</source>
        <translation>Toon alleen vensters van bureaublad</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="46"/>
        <source>Show only windows from &amp;panel&apos;s screen</source>
        <translation>Toon alleen vensters van &amp;balk&apos;s scherm</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="53"/>
        <source>Show only minimized windows</source>
        <translation>Toon alleen geminimaliseerde vensters</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="60"/>
        <source>Raise minimized windows on current desktop</source>
        <translation>Verhef geminimaliseerde vensters op huidige bureaublad</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="77"/>
        <source>Window &amp;grouping</source>
        <translation>Venster&amp;groepering</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="86"/>
        <source>Show popup on mouse hover </source>
        <translation>Toon opduikvenster bij erboven zweven met muis</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="96"/>
        <source>Appearance</source>
        <translation>Uiterlijk</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="115"/>
        <source>Maximum button width</source>
        <translation>Maximale breedte van knop</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="128"/>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="154"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="141"/>
        <source>Maximum button height</source>
        <translation>Maximale knophoogte</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="174"/>
        <source>Use icons by WindowClass, if available</source>
        <translation>Gebruik pictogrammen van WindowClass, indien beschikbaar</translation>
    </message>
    <message>
        <source>Show windows from current desktop</source>
        <translation type="vanished">Toon vensters van huidig bureaublad</translation>
    </message>
    <message>
        <source>Show windows from all desktops</source>
        <translation type="vanished">Toon vensters van alle bureaubladen</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="167"/>
        <source>Auto&amp;rotate buttons when the panel is vertical</source>
        <translation>Knoppen automatisch draaien wanneer de balk verticaal is</translation>
    </message>
    <message>
        <source>Window List Appearance</source>
        <translation type="vanished">Uiterlijk van vensterlijst</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="105"/>
        <source>Button style</source>
        <translation>Stijl van knoppen</translation>
    </message>
    <message>
        <source>Max button width</source>
        <translation type="vanished">Maximale knopbreedte</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="67"/>
        <source>Close on middle-click</source>
        <translation>Sluiten bij middelklik</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="45"/>
        <source>Icon and text</source>
        <translation>Pictogram en tekst</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="46"/>
        <source>Only icon</source>
        <translation>Alleen pictogram</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="47"/>
        <source>Only text</source>
        <translation>Alleen tekst</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="49"/>
        <source>Current</source>
        <translation>Huidig</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lxqt-panel/plugin-taskbar/taskbar_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>LXQtTaskBar</name>
    <message>
        <location filename="../../../lxqttaskbar.cpp" line="644"/>
        <source>Activate task %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtTaskButton</name>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="514"/>
        <source>Application</source>
        <translation>Toepassing</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="548"/>
        <source>To &amp;Desktop</source>
        <translation>Naar &amp;bureaublad</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="550"/>
        <source>&amp;All Desktops</source>
        <translation>&amp;Alle bureaubladen</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="558"/>
        <source>Desktop &amp;%1</source>
        <translation>Bureaublad &amp;%1</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="565"/>
        <source>&amp;To Current Desktop</source>
        <translation>&amp;Naar huidig bureaublad</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="573"/>
        <source>&amp;Move</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="576"/>
        <source>Resi&amp;ze</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="583"/>
        <source>Ma&amp;ximize</source>
        <translation>Ma&amp;ximaliseren</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="590"/>
        <source>Maximize vertically</source>
        <translation>Verticaal maximaliseren</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="595"/>
        <source>Maximize horizontally</source>
        <translation>Horizontaal maximaliseren</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="601"/>
        <source>&amp;Restore</source>
        <translation>&amp;Herstellen</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="605"/>
        <source>Mi&amp;nimize</source>
        <translation>Mi&amp;nimaliseren</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="611"/>
        <source>Roll down</source>
        <translation>Uitrollen</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="617"/>
        <source>Roll up</source>
        <translation>Oprollen</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="625"/>
        <source>&amp;Layer</source>
        <translation>&amp;Laag</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="627"/>
        <source>Always on &amp;top</source>
        <translation>Altijd bovenop</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="633"/>
        <source>&amp;Normal</source>
        <translation>&amp;Normaal</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="639"/>
        <source>Always on &amp;bottom</source>
        <translation>Altijd onderop</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="647"/>
        <source>&amp;Close</source>
        <translation>&amp;Sluiten</translation>
    </message>
</context>
<context>
    <name>LXQtTaskGroup</name>
    <message>
        <location filename="../../../lxqttaskgroup.cpp" line="83"/>
        <source>Group</source>
        <translation>Groep</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskgroup.cpp" line="85"/>
        <source>Close group</source>
        <translation>Sluit groep</translation>
    </message>
</context>
<context>
    <name>LXQtTaskbarConfiguration</name>
    <message>
        <source>LXQt Task Manager Settings</source>
        <translation type="vanished">Instellingen voor taakbeheerder van LXQt</translation>
    </message>
    <message>
        <source>Window List Content</source>
        <translation type="vanished">Inhoud van vensterlijst</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="14"/>
        <source>Task Manager Settings</source>
        <translation>Instellingen van taakbeheerder</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Algemeen</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="43"/>
        <source>Show only windows from desktop</source>
        <translation>Toon alleen vensters van bureaublad</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="55"/>
        <source>Show only windows from &amp;panel&apos;s screen</source>
        <translation>Toon alleen vensters van &amp;balk&apos;s scherm</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="62"/>
        <source>Show only minimized windows</source>
        <translation>Toon alleen geminimaliseerde vensters</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="69"/>
        <source>Raise minimized windows on current desktop</source>
        <translation>Verhef geminimaliseerde vensters op huidige bureaublad</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="83"/>
        <source>Cycle windows on wheel scrolling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="93"/>
        <source>Window &amp;grouping</source>
        <translation>Venster&amp;groepering</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="102"/>
        <source>Show popup on mouse hover</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show popup on mouse hover </source>
        <translation type="vanished">Toon opduikvenster bij erboven zweven met muis</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="112"/>
        <source>Appearance</source>
        <translation>Uiterlijk</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="131"/>
        <source>Maximum button width</source>
        <translation>Maximale breedte van knop</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="144"/>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="170"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="157"/>
        <source>Maximum button height</source>
        <translation>Maximale knophoogte</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="190"/>
        <source>Use icons by WindowClass, if available</source>
        <translation>Gebruik pictogrammen van WindowClass, indien beschikbaar</translation>
    </message>
    <message>
        <source>Show windows from current desktop</source>
        <translation type="vanished">Toon vensters van huidig bureaublad</translation>
    </message>
    <message>
        <source>Show windows from all desktops</source>
        <translation type="vanished">Toon vensters van alle bureaubladen</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="183"/>
        <source>Auto&amp;rotate buttons when the panel is vertical</source>
        <translation>Knoppen automatisch draaien wanneer de balk verticaal is</translation>
    </message>
    <message>
        <source>Window List Appearance</source>
        <translation type="vanished">Uiterlijk van vensterlijst</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="121"/>
        <source>Button style</source>
        <translation>Stijl van knoppen</translation>
    </message>
    <message>
        <source>Max button width</source>
        <translation type="vanished">Maximale knopbreedte</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="76"/>
        <source>Close on middle-click</source>
        <translation>Sluiten bij middelklik</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="45"/>
        <source>Icon and text</source>
        <translation>Pictogram en tekst</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="46"/>
        <source>Only icon</source>
        <translation>Alleen pictogram</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="47"/>
        <source>Only text</source>
        <translation>Alleen tekst</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="49"/>
        <source>Current</source>
        <translation>Huidig</translation>
    </message>
</context>
</TS>
